<?php

namespace App\Console;

use App\Service\BackupService;
use App\Service\DatabaseService;
use App\Service\Traits\SelectDatabaseQuestion;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Question\ChoiceQuestion;
use Symfony\Component\Finder\Finder;

class RestoreDatabase extends Command
{
    use SelectDatabaseQuestion;

    protected static $defaultName = 'db:restore';

    public function __construct(
        private DatabaseService $db,
        private BackupService $bs,
    )
    {
        parent::__construct();
    }

    protected function configure(): void
    {
        $this->addArgument('name', InputArgument::OPTIONAL, 'Database name');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $question = $this->getHelper('question');
        $db = $this->getDatabaseName($input, $output);

        $finder = new Finder();
        $finder->in(__DIR__ . '/../..');
        $files = [sprintf('%s_backup.sql', $db)];
        foreach ($finder->files()->name('*_backup.sql') as $file) {
            $files[] = $file->getFilename();
        }
        $selectQuestion = new ChoiceQuestion('Backup name (*_backup.sql): ', $files);
        $fileName = $question->ask($input, $output, $selectQuestion);

        $this->bs->restore($db, $fileName);

        return Command::SUCCESS;
    }
}